#
# spec file for package antimicro
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           antimicro
Version:        2.23
Release:        bp156.4.8
Summary:        Graphical program used to map keyboard keys and mouse controls to a game-pad
License:        GPL-3.0-or-later
Group:          Hardware/Joystick
URL:            https://github.com/AntiMicro/%{name}
Source0:        %{name}-%{version}.tar.gz
Patch0:         remove_datetime_aboutdialog.patch
Patch1:         rpmlint.patch
Patch2:         remove_qt5_wrap_cpp.patch
Patch3:         antimicro-gcc11-fix.patch
BuildRequires:  cmake
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  libqt5-qttools-devel
BuildRequires:  pkgconfig
BuildRequires:  shared-mime-info
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xtst)

%description
AntiMicro is a graphical program that can be used to map keyboard
keys and mouse controls to a game-pad. This functionality is useful
for playing games with no built-in or poor game-pad support.

%prep
%autosetup -p1

%build
%cmake -LA
%cmake_build

%install
%cmake_install
%find_lang %{name} --with-qt
%fdupes %{buildroot}%{_datadir}
%suse_update_desktop_file -r %{name} System HardwareSettings
mv gpl.txt LICENSE

%post
%desktop_database_post
%mime_database_post

%postun
%desktop_database_postun
%mime_database_postun

%files
%license LICENSE
%doc Changelog README.md
%{_bindir}/%{name}
%{_datadir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/mime/packages/%{name}.xml
%{_datadir}/pixmaps/%{name}.png
%{_mandir}/man?/%{name}.?%{?ext_man}

%changelog
* Sat Jun  5 2021 Илья Индиго <ilya@ilya.pp.ua>
- Added patch antimicro-gcc11-fix.patch for fix gcc11 build.
* Sat Jul 20 2019 Илья Индиго <ilya@ilya.pp.ua>
- Rename package from AntiMicro to antimicro
- Refresh spec-file via spec-cleaner and manual optimizations
  * Add %%cmake_build macro
  * Add %%license macro
  * Add %%autopatch macro
  * Rename gpl.txt to LICENSE
- Rename patches:
  * antimicro_remove_datetime_aboutdialog.patch
    to remove_datetime_aboutdialog.patch
  * antimicro_rpmlint.patch to rpmlint.patch
- Change patch remove_datetime_aboutdialog.patch (from -p0 to -p1)
* Fri May 18 2018 mlin@suse.com
- Add remove_qt5_wrap_cpp.patch
  * Fix build error by removed redundant QT5_WRAP_CPP() call from CMakeLists
* Thu Feb  9 2017 aloisio@gmx.com
- Update to version 2.23
  * Fixed portable version. (issue #37)
  * Added ability to specify logging level and file in config
    dialog. (issue #50)
  * Updated build system to find libraries on Windows systems
    instead of using explicit paths. (issue #43)
  * Added relevant window information to debug messages
    related to auto profiles. (issue #46)
  * Fixed issue with anything in profile name after first
    period being truncated. (issue #70)
  * Fixed issues with SDL 2.0.5 on all platforms. (issue #71)
  * Added support for additional small-case Latin characters
    when using Xtest. (issue #49)
  * Added inclusion of README-SDL.txt when building Windows
    distributables.
  Version 2.22
  * Fixed a segfault on startup issue affecting some Linux
    distributions
  * Fixed issues with SDL 2.0.4 on Windows.
  * Updated documentation and URLs in code to note transition
    in management.
  * Updated translations and added new ones.
  * Added code to revert all virtual buttons to beginning of
    slot list before a set switch.
  * Build system updates
  * Fixed a bug where invalid joystick was inserted into
    device list.
  * Modified to hide turbo mode combobox for regular buttons
  * Changed to allow blank config for auto profile entries
    again.
  * Fixed matching by process filename in AutoProfileWatcher
- Added antimicro_rpmlint.patch
- Updated source and home URLs
* Sun Jan 24 2016 kieltux@gmail.com
- Update to 2.2.1
  * Changed unplug routine slightly. The old behavior was slightly
    wrong anyway but the old behavior did not work with SDL 2.0.4.
  * Changes to some acceleration curves. Both the output values and
    the input offsets were changed to make mouse movement looser.
  * Removed First Run Wizard from program. In the end, that wizard
    was causing more problems for other users than it was worth.
  * Add arguments property for Execute slots.
  * Allow a real absolute mouse to be used with uinput support.
    Previously, relative mouse movement was being used to fake an
    absolute position for the mouse pointer. The WiimoteGlue project
    provided a way to allow uinput to send absolute mouse pointer
    events when using uinput.
  * Fixed set changing with analog triggers.
* Sat Oct 31 2015 sor.alexei@meowr.ru
- Update to 2.20.2 (changes since 2.17):
  * Perform event simulation in its own thread. Timer used for
    mouse speed calculations has improved as a result.
  * Slow down Enhanced Precision mouse acceleration curve slightly.
    Changes were mainly due to overall mouse emulation being tweaked.
  * Using a simulated event to click the minimise button in title
    bar now works on Windows. The move to using a dedicated thread
    for event simulation allows that to work now.
  * Fix some threading issues when using X11.
  * Fix excessive CPU load on startup when no controller is connected.
  * Fix overly active timer used to reset acceleration distances
    when no events are returned from SDL in a given gamepad poll.
  * Change behaviour of 4 Way Cardinal mode for DPads. Diagonals
    are no longer counted as a dead zone. This change is more
    likely temporary. Up+Right - Up, Down+Right - Right,
    Down+Left - Down, Up+Left - Left.
  * Add curve options for extra acceleration.
  * Fix bug when App Settings Wizard would pop up when not needed.
  * Fix SDL 1.2 build support.
  * Fix issue with SDL thread not being stopped due to connections
    not being made in some situations.
  * Fix loading of a profile from a second instance.
  * Fix problem with main window not being populated after the
    App Settings Wizard was finished.
  * Fix another portion of the program that assumed that a
    controller would be connected at startup. Fixes excessive CPU
    load.
  * Add --next to allow multiple profiles to be loaded in one
    command call.
  * Add a flag to settings file when wizard is finished. Don't
    depend on any other settings being changed during an
    application run.
  * Fix issue with inserting Pause slots.
  * Fix issue with blank application filepath being matched for
    auto profile support.
  * Make sure Game Controller Mapping dialog window reads raw
    joystick events. This should fix problems regarding improper
    mapping causing controller elements to no longer be mappable.
  * Make Set Change slots activate on button release instead of
    button press.
  * Tweak the locking being performed in various portions of the
    application.
  * Fix a problem with blank info window appearing when escaping
    from window capture utility dialog.
  * Fix issues with document-save-as icon staying displayed after
    resetting a profile.
  * Fix "Media Next" key binding for virtual keyboard.
  * Fix various issues regarding binding slots in the
    Advanced Edit dialog window.
  * Replace usage of QElapsedTimer with QTime for mouse movement
    calculations.
  * Change XTest pointer acceleration when starting the application.
  * Allow release slot to have a 0 ms interval. This is useful for
    people who use a gamepad poll rate less than 10 ms.
  * Change minimise to tray code to work better with latest versions
    of GNOME and Unity.
  * Transfer travel distance axis changes when switching sets.
  * Change Enhanced Precision and Easing Quad/Cubic acceleration
    curves.
  * Add Simplified Chinese, Sebian, and Japanese translations.
* Wed Aug  5 2015 sor.alexei@meowr.ru
- Update to 2.17 (changes since 2.13):
  * Refactor extra axis acceleration. This revision uses individual
    gamepad polls again. Other changes in the code have made
    switching back feasible. With minor adjustments, the mouse will
    be looser but very controllable.
  * Add longer duration for extra axis acceleration. This allows
    extra acceleration to be performed over a period of time as
    opposed to just one gamepad poll.
  * Do not write empty names tag in profiles if no custom button
    names have been specified.
  * Allow mouse history buffer size to go up to 100.
  * Allow diagonal range to go up to 90 degrees.
  * Remove old mouse speeds from mouse history buffer if stick has
    been returned to the dead zone. History buffer will be filled
    with zeroes.
  * Omit hotplugging dependent code when compiling against SDL 1.2.
  * Fix dpad pointer bug when certain QueuedConnection slots are
    executed.
  * Change routine for extra acceleration for mouse movement. The
    new version is a bit faster and more responsive than the
    previous version.
  * Add release circle setting for spring mouse mode. This can be
    used to have the mouse return to a region around a character
    based on the last detected direction of an analog stick.
  * Add a sub-menu to the virtual keyboard. Some multimedia and
    browser keys can now be selected.
  * Add Execute slot type. A program can be set to launch when a
    slot is activated.
  * Add Text Entry slot type. You can now have a string of text
    typed when a slot is activated. This can be useful for
    inputting common commands in games.
  * Add proper interpolation to determine the start of diagonal
    regions of analog sticks. This is used for mouse movement in
    order to determine the proper starting dead zone point.
  * Change Enhanced Precision mouse acceleration curve. The new
    changes in the curve should be much looser than before.
  * Fix --unload command line option. Enforce reloading of config
    file when finished.
  * Fix issue with spring mouse mode where the mouse would
    temporarily return to center when switching stick directions
    quickly.
  * Fix some bindings in the virtual keyboard when using SendInput
    for the event generator.
  * Fix issue with widgets used to update stick and dpad delay. The
    spinbox can now be used to edit the delay.
  * Reduce multiple instances of some objects. Reduces memory
    usage slightly.
  * Loosen initial mouse movement experienced after going outside
    the dead zone.
  * Add option in the mouse settings section that would allow
    antimicro to reset the acceleration values being used for the
    uinput virtual mouse pointer. This is useful after playing
    older GNU/Linux games that change the acceleration settings for
    all mouse pointers after a game exits. Postal 2 and Doom 3 are
    two examples of games in my game library that exhibit this
    behaviour.
  * Queue all events before performing any actions. The priority of
    various events has been changed as well.
  * Add option to change the gamepad poll rate used by the
    application. By default, the old 10 ms poll rate will be used.
  * Bundle a few backup icon files. Mainly useful on SteamOS since
    the themes used don't bundle a couple of essential icons that
    are expected to be present.
  * Change Enhanced Precision acceleration curve. The curve has
    been slowed down slightly.
  * Change how initial mouse movement is performed when the gamepad
    poll rate and the mouse refresh rate differ.
  * Flash interface buttons after restoring the main window from
    the tray icon.
  * Tweak mouse movement remainder routine. Remainders now only
    apply when the direction along an axis is the same.
  * Raise maximum cycle reset time to 60 seconds.
  * Fix improper cycle reset interval.
* Mon Apr 13 2015 kieltux@gmail.com
- Update to 2.13
  * Updated extra axis acceleration routine. Now, extra acceleration is
    calculated after an axis has stopped moving past the assigned threshold
    in one gamepad poll.
  * Stick presets now change the diagonal range of a stick. This is mainly
    beneficial for mouse control changes so that 65 degrees is used by default.
  * Added a screen selector for Spring mouse mode in settings menu.
  * Added a small language selection portion to the settings menu.
  * Added a small logger. Please run antimicro with "--log-level debug" in order
    to get output about button presses.
  * Implemented a small wizard that will be run when antimicro is launched
    for the first time. It currently only has a page for editing some of the mouse
    settings and a page for associating antimicro with .amgp files on Windows.
  * Show slots that are active for a stick modifier button on the main interface.
    The text for the main stick direction buttons will be prefixed with the
    currently active slots of the stick modifier button.
  * Corrected issue with stick and dpad events not getting activated on a set
    change. Events were being queued but not executed.
* Mon Mar 16 2015 sor.alexei@meowr.ru
- Update to 2.12 (changes since 2.10.1):
  * Adjusted the Enhanced Precision, Easing Quadratic, and
    Easing Cubic mouse acceleration curves. The low end of each
    curve has been loosened a bit and the rest of the curves have
    been adjusted accordingly. Comparing the two versions, the
    resulting mouse speed for a given axis point is slightly lower
    in the new versions for most of the curve. The extreme low end
    and the extreme high end of the curves will be slightly faster.
  * Added a set changing slot.
  * Added AppData for use when packaging on Linux thanks to Jeff Backus.
  * Fixed bug with mouse wheel event methods for axes which resulted
    in negative values being passed to the event timer.
  * Queue stick and dpad events. Allows for better control of 8-way
    sticks and dpads.
  * Added option for extra mouse acceleration. Enabling that option
    will increase the speed of the mouse based on the amount an
    axis has travelled in onegamepad poll and the set multiplier.
    This will greatly affect how the mouse behaves and it will make
    mouse movement looser. Using this feature can be problematic if
    the analog stick on your controller is worn out and loose.
  * Corrected issue with extra mouse sync events occurring when not
    needed (0,0 events). This change seems to have smoothed out
    mouse movement on the low end of an axis a bit.
  * Tweaked controller unplug workaround to still invoke release
    events for axes and buttons. For triggers, the release value
    is modified from what is provided by SDL so an unplug event
    will cause a release event to occur for the triggers.
* Wed Feb  4 2015 kieltux@gmail.com
- updated to 2.10.1
  * Changed event handler fallback method under Linux.
  * Changed interface of Assignments page in Advanced Button Dialog.
  * Reset set number upon changing profiles.
  * Added "About Development" tab to About Dialog.
  * Fixed dynamic text resizing in Button Edit Dialog under Linux.
  * Fixed launching a second instance in order to load a profile in the
    first instance.
  * Changed allowed values for easing duration. The minimum value has
    been lowered to 0.0 and the maximum value has been increased to 5.0.
  * Added a stick modifier button.
  * Increased idle mouse timer interval to 100 ms.
  * Added a load profile slot. You can now tell the program to load a
    different profile upon pressing a button.
  * Added gradient functionality for the high end of the Easing Quadratic
    and Easing Cubic mouse acceleration curves.
  * Raise process priority on Windows. On Linux, the priority of the
    main thread has been increased.
  * Take multiple direction buttons into account when assigning set
    switching to stick buttons.
  * If uinput is enabled but not usable at runtime then XTest will be
    used as a fallback option for the Linux version.
  * Tweaked Gradient and Pulse turbo modes to make them a bit tighter. A
    lower delay will be needed in profiles to achieve a similar control
    from previous versions. On the plus side, this has been tested to work
    with FlatOut 2 fairly well. It is good enough to use and actually
    win some races against AI opponents.
  * Added analog control for mouse wheel buttons that are mapped to an
    axis button.
  * Tweaked mouse movement code to improve mouse accuracy. This is mainly
    due to discovering the QElapsedTimer class that is included in Qt.
  * Fixed middle mouse button binding when using the uinput event handler
    on Linux.
  * Fixed memory leaks that were discovered by Valgrind.
  * Added mouse refresh rate as an option. Please be mindful of how your
    system behaves if you set the refresh rate to a low value like 1 ms.
    In the worst case scenario, you could end up dedicating one CPU core
    on just the antimicro process. Also, on Windows, you will want to make
    sure to disable the "Enhance Pointer Precision" option if you use a low
    value otherwise Windows will severely slow down the mouse pointer.
  * Added an application level mouse smoothing option. The older button
    level smoothing option has been removed. The old option didn't do
    much since it only dealt with the partial distance remainder.
  * Button responsiveness has been improved. The old mouse movement code
    was creating a bottleneck for button processing which would result in
    a slight delay.
  * Changed mouse movement code. The overall mouse movement should be
    smoother now.
  * Allow the Windows setting "Enhance Pointer Precision" to be disabled
    while antimicro is running.
  * Changes to Auto Profile to allow more variables for matching
  * Changed how windows are grabbed in X on Linux.
  * Minor fix for Gradient and Pulse turbo modes.
* Fri Nov  7 2014 kieltux@gmail.com
- Add patch antimicro_remove_datetime_aboutdialog.patch
  remove DATE, TIME from aboutdialog to avoid unneccessary rebuilds
* Fri Nov  7 2014 kieltux@gmail.com
- Update to 2.8.1:
  * Fixed some buttons in virtual keyboard when program is
  using uinput support.
  * Fixed Update Joysticks option for SDL 1.2 users.
  * Added delay settings for analog sticks and dpads.
  * Added two new mouse acceleration curves.
  * Major refactor to mouse event generation.
  * Made uinput support a runtime option for Linux users.
  * Added right click context menus for buttons in main interface.
  * Fixed issue with Game Controller Mapping dialog.
  * Fixed an issue with incorrect profile names being displayed
  in the profile combobox.
  * Changed button groups in the main interface to update
  immediately when a stick or dpad mode has been changed.
  * Initial removal of old joystick abstraction support in
  interface when using SDL 2.
  * Added more key aliases for uinput support.
  * Force higher dead zones for axes in Game Controller
  Mapping window.
  * Fixed virtual keyboard in Button Edit Dialog window for
  Linux users utilizing XTest support.
  * Display some minor mouse stats in Mouse Settings dialog.
  * Alter Analog Stick dialog window to show some new stats.
  * Added square stick to circle stick conversion.
  * Fixed issue with VK_LSHIFT and VK_RSHIFT aliases not
  being saved properly on Windows.
  * xinput is used for the uinput virtual pointer.
* Tue Sep 30 2014 sor.alexei@meowr.ru
- Update to 2.6.
- Remove antimicro_pro.patch: upstream is on cmake now.
- Remove antimicro_desktop.patch and use %%suse_update_desktop_file.
- Minor spec cleanup.
- Move to Qt5 (and make openSUSE 13.1 a minimal requirement).
* Mon Apr 21 2014 kieltux@gmail.com
- Patch for antimicro.pro (wrong test parameter for SDL in
  upstream).
- Conditional build process: SDL2 with openSUSE >= 13.1.
* Mon Apr 21 2014 kieltux@gmail.com
- Update to 2.2:
  * Added example controller display to Game Controller Mapping
  dialog window.
  * Added Auto Profile support. Allows for profiles to be associated
  with specific applications.
  * Added a press time slot type. That slot type is used to have
  keys active for a specific period of time.
  * Allow Pause slots to have a 0 second interval. Allows for a
  forced key release.
  * Fixed 8-Way D-Pad mode.
  * Fixed preset options in various dialogs to account for new
  aliases.
  * Fixed ampersand rendering in set buttons.
  * Fixed spring mouse mode dimension support.
* Fri Mar  7 2014 kieltux@gmail.com
- Update to 2.1:
  * Added new stick and dpad modes.
  * Added set names.
  * Fixed QSettings usage to reduce reads and write to config file.
* Fri Feb 21 2014 kieltux@gmail.com
- Spec file cleanup.
* Thu Feb 13 2014 kieltux@gmail.com
- Update to 2.0.1:
  * Active keyboard keys now use a reference count.
  * A release delay has been added to release slot events.
  * The recent profile list is now updated when a profile is added or
  removed from.
* Tue Feb  4 2014 kieltux@gmail.com
- Initial import based on specfile from
  Travis Nickles <nickles.travis@gmail.com> - antimicro-2.0-1.fc20.src.rpm
